==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/postgresql/psycopg/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Psycopg")
url = "http://initd.org/software/psycopg/"
doc = """
Description
-----------
From the Psycopg website: "It was written from scratch with the aim of
being very small and fast, and stable as a rock."  Written by initd.org
volunteers.

Support
-------
Supported Platforms:

  - Linux/BSD

Connection Properties
---------------------
* host  -- This is the name of the database host, or, on Linux,
  directory containing the network socket (required)
* dbname -- This is the database to use (required)
* port -- Port that PostgreSQL is running on (defaults to 5432) (optional)

Examples
--------
  [myconn]
  provider=psycopg        # Use the psycopg adapter
  host=localhost          # The hostname/IP of the postgresql host
  dbname=mydb             # The name of the pg database

Notes
-----
1. Available in Debian [sid,woody] as: "apt-get install python-popy
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/postgresql/psycopg/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Psycopg")
url = "http://initd.org/software/initd/psycopg/"
doc = """
Description
-----------
From the Psycopg website: "It was written from scratch with the aim of
being very small and fast, and stable as a rock."  Written by initd.org
volunteers.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP (Installer available)

Connection Properties
---------------------
* host  -- This is the name of the database host, or, on Linux,
  directory containing the network socket (required)
* dbname -- This is the database to use (required)
* port -- Port that PostgreSQL is running on (defaults to 5432) (optional)

Examples
--------
  [myconn]
  provider=psycopg        # Use the psycopg adapter
  host=localhost          # The hostname/IP of the postgresql host
  dbname=mydb             # The name of the pg database

Notes
-----
1. This is the driver of choice for PostgreSQL.

2. Available in Debian as: "apt-get install python-psycopg".

3. Windows installer available at: http://stickpeople.com/projects/python/win-psycopg/.

4. This driver is fully functional with no known serious problems.
"""
